/**
 * Authentication JavaScript for RiversMall Job Board
 * Handles login, logout, and user status management
 */

class AuthManager {
    constructor() {
        this.apiBaseUrl = 'https://kp2382yeh5.execute-api.us-west-2.amazonaws.com/dev';
        this.init();
    }

    /**
     * Initialize authentication system
     */
    init() {
        this.handleTokenFromURL();
        this.checkAuthStatus();
        this.bindEvents();
    }

    /**
     * Bind click events to auth buttons
     */
    bindEvents() {
        // Login button
        const loginBtn = document.getElementById('auth-login-btn');
        if (loginBtn) {
            loginBtn.addEventListener('click', (e) => {
                e.preventDefault();
                this.login();
            });
        }

        // Logout button
        const logoutBtn = document.getElementById('auth-logout-btn');
        if (logoutBtn) {
            logoutBtn.addEventListener('click', (e) => {
                e.preventDefault();
                this.logout();
            });
        }
    }

    /**
     * Check current authentication status
     */
    async checkAuthStatus() {
        try {
            const authToken = localStorage.getItem('auth_token');
            const headers = {
                'Content-Type': 'application/json',
            };
            
            const fetchOptions = {
                method: 'GET',
                headers: headers
            };
            
            // Add Authorization header if we have a token
            if (authToken) {
                headers['Authorization'] = `Bearer ${authToken}`;
                // Don't include credentials when using Authorization header
            } else {
                // Only include credentials when falling back to cookie auth
                fetchOptions.credentials = 'include';
            }
            
            const response = await fetch(`${this.apiBaseUrl}/status`, fetchOptions);

            if (response.ok) {
                const data = await response.json();
                if (data.authenticated) {
                    this.showAuthenticatedState(data.user);
                } else {
                    this.showUnauthenticatedState();
                    // Clear invalid token
                    localStorage.removeItem('auth_token');
                }
            } else {
                this.showUnauthenticatedState();
                // Clear invalid token
                localStorage.removeItem('auth_token');
            }
        } catch (error) {
            console.log('Auth status check failed:', error);
            this.showUnauthenticatedState();
            // Clear invalid token
            localStorage.removeItem('auth_token');
        }
    }

    /**
     * Show UI for authenticated user
     */
    showAuthenticatedState(user) {
        const authContainer = document.getElementById('auth-container');
        if (authContainer) {
            authContainer.innerHTML = `
                <div class="auth-user-info">
                    <span class="auth-welcome">欢迎, ${user.email || user.name || '用户'}</span>
                    <button id="auth-logout-btn" class="btn btn-outline-primary btn-sm ml-2">
                        <i class="fa fa-sign-out"></i> 退出
                    </button>
                </div>
            `;
            // Re-bind events after updating DOM
            this.bindEvents();
        }
    }

    /**
     * Show UI for unauthenticated user
     */
    showUnauthenticatedState() {
        const authContainer = document.getElementById('auth-container');
        if (authContainer) {
            authContainer.innerHTML = `
                <div class="auth-login-info">
                    <button id="auth-login-btn" class="btn btn-primary btn-sm">
                        <i class="fa fa-sign-in"></i> 登录
                    </button>
                </div>
            `;
            // Re-bind events after updating DOM
            this.bindEvents();
        }
    }

    /**
     * Redirect to login page
     */
    login() {
        window.location.href = `${this.apiBaseUrl}/login`;
    }

    /**
     * Logout user
     */
    async logout() {
        console.log('Logout clicked - starting logout process');
        
        try {
            // Clear the stored token first
            const hadToken = localStorage.getItem('auth_token');
            localStorage.removeItem('auth_token');
            console.log('Cleared localStorage token:', hadToken ? 'had token' : 'no token');
            
            // Update UI immediately
            this.showUnauthenticatedState();
            console.log('Updated UI to unauthenticated state');
            
            // Try to call the logout endpoint to invalidate server-side session
            // This might fail due to CORS when running locally, but that's okay
            try {
                console.log('Attempting server logout...');
                const response = await fetch(`${this.apiBaseUrl}/logout`, {
                    method: 'GET',
                    credentials: 'include',
                    mode: 'cors'
                });
                console.log('Server logout response:', response.status, response.statusText);
            } catch (error) {
                console.log('Server logout failed (expected when running locally):', error.message);
                // This is expected when running locally due to CORS
            }
            
            // Show success message
            this.showSuccessMessage('已退出登录');
            console.log('Logout completed successfully');
            
        } catch (error) {
            console.error('Logout error:', error);
            // Force logout by clearing local state anyway
            localStorage.removeItem('auth_token');
            this.showUnauthenticatedState();
            this.showSuccessMessage('已退出登录');
        }
    }

    /**
     * Handle authentication callback (called from callback page)
     */
    handleCallback() {
        // Check if we're on a callback page with success
        const urlParams = new URLSearchParams(window.location.search);
        if (urlParams.get('auth') === 'success') {
            // Show success message
            this.showSuccessMessage('登录成功！');
            // Check auth status to update UI
            setTimeout(() => {
                this.checkAuthStatus();
            }, 1000);
        } else if (urlParams.get('auth') === 'error') {
            // Show error message
            this.showErrorMessage('登录失败，请重试。');
        }
    }

    /**
     * Show success message
     */
    showSuccessMessage(message) {
        this.showMessage(message, 'success');
    }

    /**
     * Show error message
     */
    showErrorMessage(message) {
        this.showMessage(message, 'error');
    }

    /**
     * Show message to user
     */
    showMessage(message, type = 'info') {
        // Create message element
        const messageDiv = document.createElement('div');
        messageDiv.className = `alert alert-${type === 'error' ? 'danger' : type === 'success' ? 'success' : 'info'} alert-dismissible fade show`;
        messageDiv.style.position = 'fixed';
        messageDiv.style.top = '20px';
        messageDiv.style.right = '20px';
        messageDiv.style.zIndex = '9999';
        messageDiv.innerHTML = `
            ${message}
            <button type="button" class="close" data-dismiss="alert">
                <span>&times;</span>
            </button>
        `;

        // Add to page
        document.body.appendChild(messageDiv);

        // Auto-remove after 5 seconds
        setTimeout(() => {
            if (messageDiv.parentNode) {
                messageDiv.parentNode.removeChild(messageDiv);
            }
        }, 5000);
    }

    /**
     * Handle authentication token from URL parameter
     */
    handleTokenFromURL() {
        const urlParams = new URLSearchParams(window.location.search);
        const authToken = urlParams.get('auth_token');
        
        if (authToken) {
            // Store token in localStorage
            localStorage.setItem('auth_token', authToken);
            
            // Clean up URL by removing the token parameter
            const newUrl = new URL(window.location);
            newUrl.searchParams.delete('auth_token');
            window.history.replaceState({}, document.title, newUrl.toString());
            
            // Show success message
            this.showSuccessMessage('登录成功！');
        }
    }
}

// Initialize authentication when DOM is ready
document.addEventListener('DOMContentLoaded', function() {
    window.authManager = new AuthManager();
    
    // Handle callback if on callback page
    if (window.location.pathname.includes('/callback') || window.location.search.includes('auth=')) {
        window.authManager.handleCallback();
    }
});

// Export for use in other scripts
if (typeof module !== 'undefined' && module.exports) {
    module.exports = AuthManager;
} 